@@ -275,8 +275,7 @@ void MainWindow::newConnection(const QUrl &newUrl, bool switchFullscreenWhenConn
     }
 
     if (m_protocolInput && m_addressInput) {
-        int index = m_protocolInput->findText(url.scheme());
-        if (index>=0) m_protocolInput->setCurrentIndex(index);
+        m_protocolInput->setCurrentText(url.scheme());
         m_addressInput->setText(url.authority());
     }
 
@@ -303,7 +302,7 @@ void MainWindow::newConnection(const QUrl &newUrl, bool switchFullscreenWhenConn
     // if the user press cancel
     if (! prefs->showDialogIfNeeded(this)) return;
 
-    view->showDotCursor(prefs->showLocalCursor() ? RemoteView::CursorOn : RemoteView::CursorOff);
+    view->showLocalCursor(prefs->showLocalCursor() ? RemoteView::CursorOn : RemoteView::CursorOff);
     view->setViewOnly(prefs->viewOnly());
     if (! switchFullscreenWhenConnected) view->enableScaling(prefs->windowedScale());
 
@@ -350,9 +349,10 @@ void MainWindow::selectFromRemoteDesktopsModel(const QModelIndex &index)
 
     if (!urlString.isEmpty() && m_protocolInput && m_addressInput) {
         const QUrl url(urlString);
+        m_addressInput->blockSignals(true); // block signals so we don't filter the address list on click
         m_addressInput->setText(url.authority());
-        int index = m_protocolInput->findText(url.scheme());
-        if (index>=0) m_protocolInput->setCurrentIndex(index);
+        m_addressInput->blockSignals(false);
+        m_protocolInput->setCurrentText(url.scheme());
     }
 }
 
@@ -736,7 +736,7 @@ void MainWindow::showLocalCursor(bool showLocalCursor)
     qCDebug(KRDC) << showLocalCursor;
 
     RemoteView* view = currentRemoteView();
-    view->showDotCursor(showLocalCursor ? RemoteView::CursorOn : RemoteView::CursorOff);
+    view->showLocalCursor(showLocalCursor ? RemoteView::CursorOn : RemoteView::CursorOff);
     view->hostPreferences()->setShowLocalCursor(showLocalCursor);
     saveHostPrefs(view);
 }
@@ -852,7 +852,7 @@ void MainWindow::updateActionStatus()
     setActionStatus(actionCollection()->action(QStringLiteral("show_local_cursor")),
                     enabled,
                     view ? view->supportsLocalCursor() : false,
-                    view ? view->dotCursorState() == RemoteView::CursorOn : false);
+                    view ? view->localCursorState() == RemoteView::CursorOn : false);
 
     setActionStatus(actionCollection()->action(QStringLiteral("scale")),
                     enabled,
@@ -915,6 +915,10 @@ void MainWindow::updateConfiguration()
         m_tabWidget->widget(i)->setPalette(palette);
     }
 
+    if (m_protocolInput) {
+        m_protocolInput->setCurrentText(Settings::defaultProtocol());
+    }
+
     // Send update configuration message to all views
     foreach (RemoteView *view, m_remoteViewMap) {
         view->updateConfiguration();
@@ -1063,6 +1067,7 @@ QWidget* MainWindow::newConnectionWidget()
         foreach(RemoteViewFactory *factory, m_remoteViewFactories) {
             m_protocolInput->addItem(factory->scheme());
         }
+        m_protocolInput->setCurrentText(Settings::defaultProtocol());
 
         connect(m_addressInput, SIGNAL(returnPressed()), SLOT(newConnection()));
         m_addressInput->setToolTip(i18n("Type an IP or DNS Name here. Clear the line to get a list of connection methods."));
