@@ -49,6 +49,12 @@ public:
     virtual void fire(rfbClient*) = 0;
 };
 
+class ReconfigureEvent: public ClientEvent
+{
+public:
+    void fire(rfbClient*) override;
+};
+
 class KeyClientEvent : public ClientEvent
 {
 public:
@@ -110,9 +116,11 @@ public:
     void setHost(const QString &host);
     void setPort(int port);
     void setQuality(RemoteView::Quality quality);
+    void setDevicePixelRatio(qreal dpr);
     void setPassword(const QString &password) {
         m_password = password;
     }
+    void setShowLocalCursor(bool show);
     const QString password() const {
         return m_password;
     }
@@ -130,6 +138,7 @@ public:
 Q_SIGNALS:
     void imageUpdated(int x, int y, int w, int h);
     void gotCut(const QString &text);
+    void gotCursor(const QCursor &cursor);
     void passwordRequest(bool includingUsername = false);
     void outputErrorMessage(const QString &message);
 
@@ -162,6 +171,7 @@ private:
     static char *passwdHandlerStatic(rfbClient *cl);
     static rfbCredential *credentialHandlerStatic(rfbClient *cl, int credentialType);
     static void outputHandlerStatic(const char *format, ...);
+    static void cursorShapeHandlerStatic(rfbClient *cl, int xhot, int yhot, int width, int height, int bpp);
 
     // Member functions corresponding to the above static methods.
     rfbBool newclient();
@@ -177,8 +187,10 @@ private:
     QString m_password;
     QString m_username;
     int m_port;
+    bool m_showLocalCursor;
     QMutex mutex;
     RemoteView::Quality m_quality;
+    qreal m_devicePixelRatio;
     ColorDepth m_colorDepth;
     QQueue<ClientEvent* > m_eventQueue;
     //color table for 8bit indexed colors
